@@ -612,7 +612,7 @@ int main (int argc, char* argv[], char** e) {
 	struct stat stat_buffer;
 	char* http_host_config_file_path;
 	int conf_file_path_string_size;
-	char realpath_path[PATH_MAX+2];
+	char realpath_path[MAXPATHLEN+2];
 	char* dirname_path;
 	char* dirname_path2;
 	FILE* fp;
@@ -1157,7 +1157,7 @@ void check_target(const char* newroot,
 
 	/* 2) script must be executable by other */
 	if (!( (file_stats->st_mode & S_IXOTH)))
-		fatal_error("%s not world executable\n",escape(target));
+		fatal_error("%s not world executable. Make sure your script is chmod +x!\n",escape(target));
 
 	/* 3) script is not owned by WEB_USER or WEB_GROUP */
 	if ((pass = getpwuid(file_stats->st_uid)) == NULL)
